from sshtunnel import SSHTunnelForwarder
from sqlalchemy.orm import sessionmaker
from sqlalchemy import create_engine


def SSHDB(input_remote_server_IP, input_remote_server_port, input_ssh_username, 
    input_ssh_password, input_remote_bind_address, input_remote_bind_address_port, input_db_server, input_db_name, input_query):

    with SSHTunnelForwarder(
        (input_remote_server_IP, int(input_remote_server_port)), #Remote server IP and SSH port
        ssh_username = input_ssh_username,
        ssh_password = input_ssh_password,
        remote_bind_address=(input_remote_bind_address, int(input_remote_bind_address_port))) as server: 
            
        server.start() #start ssh sever
        print ('Server connected via SSH')
        
        #connect to PostgreSQL
        local_port = str(server.local_bind_port)
        engine = create_engine(input_db_server + local_port + input_db_name)

        Session = sessionmaker(bind=engine)
        session = Session()
        print ('Database session created')
        
        #test data retrieval
        print ('Executing Query')
        test = session.execute(input_query)
        for row in test:
            print(row['otp'])
            otp = row['otp']
            
        session.close()
        return otp



import pathlib
from setuptools import setup

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

setup(
    name="pj_rf_sshdb",
    version="0.0.1",
    description="Get Data from DB via SSh during execution using Robot Framework..",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/",
    author="PJ Gevana",
    author_email="patdroidz@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["pj_rf_sshdb"],
    include_package_data=True,
    # install_requires=["requests"],
)
